<?php
/**
 * Advertisement section
 *
 * This is the template for the content of Advertisement section
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */
if ( ! function_exists( 'edumag_pro_add_advertisement_section' ) ) :
  /**
   * Add Advertisement section
   *
   *@since EduMag Pro 1.0
   */
  function edumag_pro_add_advertisement_section() {

    // Check if Advertisement is enabled on frontpage
    $advertisement_section_enable = apply_filters( 'edumag_pro_section_status', true, 'advertisement_section_enable' );
    if ( true !== $advertisement_section_enable ) {
        return false;
    }

    $options = edumag_pro_get_theme_options(); // Get theme options

    // Render Advertisement section now.
    edumag_pro_render_advertisement_section( $options );
  }
endif;
add_action( 'edumag_pro_primary_content', 'edumag_pro_add_advertisement_section', 50 );

if ( ! function_exists( 'edumag_pro_render_advertisement_section' ) ) :
  /**
   * Start Advertisement section
   *
   * @return string Advertisement content
   * @since EduMag Pro 1.0
   *
   */
    function edumag_pro_render_advertisement_section( $options ) {
        $advertisement_type = $options['advertisement_section_ad_type'];
        $advertisement = ''; 

        switch ( $advertisement_type ) {

            case 'demo':
                $advertisement = '<a href="#"><img src="'. get_template_directory_uri() .'/assets/uploads/google-ad-3.jpg"></a>';
            break;

            case 'ad_image':
                $ad_image = !empty( $options['advertisement_section_ad_image'] ) ? $options['advertisement_section_ad_image'] : '' ;
                $ad_url = !empty( $options['advertisement_section_ad_url'] ) ? $options['advertisement_section_ad_url'] : '#' ;
                $new_tab = $options['advertisement_section_new_tab'] ? 'target="_blank"' : '';

                if( !empty( $ad_image ) ){
                    $advertisement = '<a href="'. esc_url( $ad_url ) .'" '. $new_tab .'><img src="'. esc_url( $ad_image ) .'"></a>';
                }
            break;

            default:
                if( ! empty( $options['advertisement_section_ad_code'] ) ) {
                    $advertisement = $options['advertisement_section_ad_code'];
                }
            break; 
        }
        if( !empty( $advertisement ) ){ ?>
            <section id="google-advertisement-3" class="widget widget_google_ad wow fadeInUp" data-wow-delay="0.3s" data-wow-duration="0.3s">
                <div class="container">
                    <?php 
                        if( 'ad_code' == $advertisement_type ){
                            echo html_entity_decode( $advertisement, ENT_QUOTES, 'UTF-8' );
                        } else{
                            echo wp_kses_post( $advertisement );
                        }
                    ?>
                </div><!-- .container -->
            </section>
        <?php } 
    }
endif;