<?php
/**
 * Trending section
 *
 * This is the template for the content of Trending  section
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */

if ( ! function_exists( 'edumag_pro_add_trending_section' ) ) :
  /**
   * Add Trending section
   *
   *@since EduMag Pro 1.0
   */
  function edumag_pro_add_trending_section() {

    // Check if Trending section is enabled on frontpage
    $trending_section_enable = apply_filters( 'edumag_pro_section_status', true, 'trending_section_enable' );
    if ( true !== $trending_section_enable ) {
      return false;
    }

    // Get Trending section details
    $section_details = array();
    $section_details = apply_filters( 'edumag_pro_filter_trending_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render Trending section now.
    edumag_pro_render_trending_section( $section_details );
  }
endif;
add_action( 'edumag_pro_primary_content', 'edumag_pro_add_trending_section', 40 );


if ( ! function_exists( 'edumag_pro_get_trending_section_details' ) ) :
  /**
   * Trending section details.
   *
   * @since EduMag Pro 1.0
   * @param array $input Trending section details.
   */
  function edumag_pro_get_trending_section_details( $input ) {
    $options = edumag_pro_get_theme_options();

    // Trending section type
    $trending_section_content_type = $options['trending_section_content_type'];

    $content = array();
    switch ( $trending_section_content_type ) {
        case 'demo':

            $title = array(
                esc_html__( 'Basic Time Management Course', 'edumag-pro' ),
                esc_html__( 'Chemical Engineering', 'edumag-pro' ),
                esc_html__( 'Photography for Beginners Masterclass', 'edumag-pro' ),
                esc_html__( 'Intoduction to  networking for beginner', 'edumag-pro' ),
                esc_html__( 'The Theory Of Sport for every ages people', 'edumag-pro' )
             );

            for ( $i=1; $i<=5; $i++ ) {
                $content[$i]['ID']           = '';
                $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/trending-course-0'. $i .'.jpg';
                $content[$i]['url']          = '#';
                $content[$i]['title']        = $title[ $i-1 ];
                $content[$i]['excerpt']      = esc_html__( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry standard dummy text ever since the 1500s.', 'edumag-pro' );
                $content[$i]['price']        = '$299.99';
                $content[$i]['likes']        = '<span class="screen-reader-text">' . esc_html__( 'Likes', 'edumag-pro' ) . '</span><a href="#"><i class="fa fa-heart"></i>35</a>';
            }
        break;

        case 'category':
            $cat_ids = '';
            if ( !empty( $options['trending_section_content_category'] ) ) {
                $cat_ids = $options['trending_section_content_category'];
            }
            
            // Bail if no valid pages are selected.
            if ( empty( $cat_ids ) ) {
                return $input;
            }
            $args = array(
                'post_type'      => 'post',
                'category__in'   => $cat_ids,
                'posts_per_page' => absint( $options['trending_section_count'] ),
                'orderby'        => 'ASC',
            );
        break;

        default:
            if ( !empty( $options['trending_courses_'. $trending_section_content_type ] ) ) {
                $cat_ids = $options['trending_courses_'. $trending_section_content_type ];
            }
            // Bail if no valid pages are selected.
            if ( empty( $cat_ids ) ) {
                return $input;
            }

            $post_type = get_taxonomy( $trending_section_content_type );

            $args = array(
                'post_type'         => $post_type->object_type[0],
                'posts_per_page'    => absint( $options['trending_section_count'] ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => $trending_section_content_type,
                        'field'     => 'id',
                        'terms'     => $cat_ids
                    )
                )
            );
        break;
    }

    if ( 'demo' != $trending_section_content_type ) {
        // Fetch posts.
        $posts = get_posts( $args );

        if ( ! empty( $posts ) ) {
            $i = 1;

            foreach ( $posts as $key => $post ) {
                $page_id = $post->ID;
                $img_array = null;

                if ( has_post_thumbnail( $page_id ) ) {
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'edumag-pro-featured-popular-article' );
                } else {
                    $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-450x300.jpg';
                }

                if ( isset( $img_array ) ) {
                  $content[$i]['img_array'] = $img_array;
                }

                $like_string =  '';
                if( function_exists( 'tp_education_like_button' ) ){
                    $like_string = tp_education_like_button();
                    $like_string = '<span class="screen-reader-text">' . esc_html__( 'Likes', 'edumag-pro' ) . '</span>' . $like_string;
                }

                $content[$i]['ID']       = $page_id;
                $content[$i]['url']      = get_permalink( $page_id );
                $content[$i]['title']    = get_the_title( $page_id );
                $content[$i]['excerpt']  = edumag_pro_trim_content( 12, $post  );
                $content[$i]['alt']      = get_the_title( $page_id );
                $content[$i]['likes']    = $like_string;          
                $i++;
            }
        }
    }

    if ( ! empty( $content ) ) {
        $input = $content;
    }
    return $input;
}
endif;
// Trending course section content details.
add_filter( 'edumag_pro_filter_trending_section_details', 'edumag_pro_get_trending_section_details' );


if ( ! function_exists( 'edumag_pro_render_trending_section' ) ) :
  /**
   * Start Trending section
   *
   * @return string Trending content
   * @since EduMag Pro 1.0
   *
   */
   function edumag_pro_render_trending_section( $content_details ) {
        $options                = edumag_pro_get_theme_options();
        $content_type           = $options['trending_section_content_type'];
        $section_title          = $options['trending_section_title'];
        $section_subtitle       = $options['trending_section_subtitle'];
        $sidebar_layout         = edumag_pro_layout();
        $sidebar_disabled_class = !is_active_sidebar( 'trending_courses_sidebar' ) ? 'sidebar-disabled' : '';
    ?>
        <section id="trending-courses" class="page-section">
            <div class="container">
                <div class="main-content <?php echo esc_attr( $sidebar_disabled_class ); ?>">

                <?php if( !empty( $section_title ) || !empty( $section_subtitle ) ) : ?>
                    <header class="entry-header wow fadeInUp" data-wow-delay="0.3s" data-wow-duration="0.3s">

                        <?php if( !empty( $section_title ) ){ ?>
                            <h2 class="entry-title"><?php echo esc_html( $section_title ); ?></h2>

                        <?php } if( !empty( $section_subtitle ) ){ ?>
                            <p class="sub-title"><?php echo esc_html( $section_subtitle ); ?></p>
                        <?php } ?>

                    </header><!-- .entry-header -->
                    <?php endif; ?>

                    <div class="course-selection clear wow fadeInUp" data-wow-delay="0.3s" data-wow-duration="0.4s">
                        <form action="<?php echo esc_url( home_url('/') ); ?>" role="search" method="get">
                            <input type="hidden" name="section" value="trending">
                            <?php if ( $content_type != 'demo' ) : ?>
                                <input type="hidden" name="taxonomy" value="<?php echo esc_attr( $content_type ); ?>">
                                <div class="pull-left select-courses">
                                    <?php
                                    $taxonomy = $content_type;
                                    $args = array(
                                        'show_option_none'   => 'Select Category',
                                        'option_none_value'   => '',
                                        'hide_empty'         => 0,              
                                        'selected'           => 1,
                                        'hierarchical'       => 1,
                                        'name'               => 'category',
                                        'class'              => '',              
                                        'taxonomy'           => $taxonomy,
                                        'value_field'        => 'slug'
                                    );

                                    wp_dropdown_categories( $args, $taxonomy );
                                    ?>
                                </div><!-- .pull-left/.select-courses -->
                            <?php endif; ?>
                            <div class="pull-left">
                                    <input type="text" name="s" placeholder="<?php esc_attr_e( 'search', 'edumag-pro' ); ?>">
                                    <button type="submit"><i class="fa fa-search"></i></button>
                            </div><!-- .pull-left -->

                        </form>

                        <div class="pull-right grid-icons">
                            <ul class="tabs">
                                <li class="tab-link active" data-tab="tab-gridview">
                                    <i class="fa fa-th-large"></i>
                                </li>
                                <li class="tab-link" data-tab="tab-listview">
                                    <i class="fa fa-th-list"></i>
                                </li>
                            </ul><!-- end .tabs -->
                        </div><!-- .pul-right/.grid-cions -->
                    </div><!-- .course-selection -->

                    <div class="courses-list three-columns">
                        <div id="tab-gridview" class="tab-content active">
                            <div class="row wow fadeInUp" data-wow-delay="0.3s" data-wow-duration="0.5s">
                            <?php 
                                $count = count( $content_details );
                                $index = 1;
                                foreach ( $content_details as $key => $content ) :
                                ?>
                                <div class="column-wrapper">
                                    <div class="course-item">   

                                        <div class="image-wrapper"> 
                                            <a href="<?php echo esc_url( $content['url'] );?>"><img src="<?php echo esc_url( $content['img_array'][0] ); ?>" alt="<?php echo esc_html( $content['title'] ); ?>"></a>
                                            <?php  if( class_exists( 'TP_Education' ) ){
                                                $post_id = $content['ID'];
                                                if( 'tp-class-category' == $options['trending_section_content_type'] ){
                                                    $price = get_post_meta( $post_id, 'tp_class_cost_value', true );          
                                                }elseif ('tp-course-category' == $options['trending_section_content_type'] ) {
                                                    $price = get_post_meta( $post_id, 'tp_course_price_value', true );
                                                }
                                                if( !empty( $price ) ){
                                                    echo '<span class="price-tag">'. esc_html( $price ) .'</span>';
                                                }
                                            } ?>
                                        </div><!-- end .image-wrapper -->

                                        <div class="course-contents-wrapper">
                                            <?php if( !empty( $content['title'] ) ){ ?>
                                            <div class="course-title">
                                                <h3><a href="<?php echo esc_url( $content['url'] );?>" class="color-black"><?php echo esc_html( $content['title'] ); ?></a></h3>
                                            </div><!-- end .course-title -->
                                            <?php } 

                                            if( !empty( $content['excerpt'] ) ){ ?>
                                            <div class="course-desc">
                                            <?php if( !empty( $content['excerpt'] ) ){ 
                                                echo '<p>'. esc_html( $content['excerpt'] ) .'</p>';
                                            } ?>
                                            </div><!-- .course-desc -->
                                            <?php } ?>

                                            <div class="course-footer-content clear">
                                                <?php if( !empty( $content['likes'] ) ){ ?>
                                                <div class="pull-left">
                                                    <div class="comments"><?php echo wp_kses_post( $content['likes'] ); ?> </div>
                                                </div><!-- end .pull-left -->
                                                <?php } ?>
                                            </div><!-- end .slide-description -->
                                        </div><!-- end .course-contents-wrapper -->
                                    </div><!-- end .course-item -->
                                </div><!-- end .column-wrapper -->

                                <?php 
                                    if( $count > 3 && ( $index % 3 == 0 ) ){
                                        echo '</div><!--.row--><div class="row wow fadeInUp" data-wow-delay="0.3s" data-wow-duration="0.5s">';
                                    }
                                    $index++;
                                    endforeach; 
                                ?>
                                <?php if( 'demo' == $content_type ) : ?>
                                <div class="column-wrapper">
                                    <div class="upcoming-courses">

                                        <h3><?php esc_html_e( 'upcoming', 'edumag-pro' ); ?> <span class="big-title"><?php esc_html_e( 'courses', 'edumag-pro' ); ?></span></h3>
                                        <p><?php esc_html_e( 'Donec feugiat ultricies accumsan. Fusce sed tempor.', 'edumag-pro' ); ?></p>
                                        <div class="view-more">
                                            <a href="#" class="btn btn-border-white"><?php esc_html_e( 'Get notified', 'edumag-pro' ); ?></a>
                                        </div><!--.button-->
                                    </div><!--.upcoming-courses-->
                                    <div id="subscribe-newsletter" class="popup-form">
                                        <section id="blog_subscription-2" class="widget jetpack_subscription_widget">

                                            <h2 class="widget-title"><?php esc_html_e( 'Receive Newsletter', 'edumag-pro' ); ?></h2>
                                            <form action="#" method="post" accept-charset="utf-8" id="subscribe-blog-blog_subscription-2">
                                                <div id="subscribe-text">
                                                    <p><?php esc_html_e( 'Enter your email address to subscribe to this blog and receive notifications of new posts by email.', 'edumag-pro' ); ?></p>
                                                </div>          

                                                <p id="subscribe-email">
                                                    <label id="jetpack-subscribe-label"><?php esc_html_e( 'Email Address', 'edumag-pro' ); ?></label>
                                                    <input type="email" name="email" required="required" class="required" value="" id="subscribe-field-blog_subscription-2" placeholder="<?php esc_attr_e( 'Email Address', 'edumag-pro' ); ?>">
                                                </p>

                                                <p id="subscribe-submit">
                                                    <input type="hidden" name="action" value="subscribe">
                                                    <input type="hidden" name="source" value="http://themepalacedemo.com/foodland-pro/">
                                                    <input type="hidden" name="sub-type" value="widget">
                                                    <input type="hidden" name="redirect_fragment" value="blog_subscription-2">
                                                    <input type="submit" value="Subscribe" name="jetpack_subscriptions_widget">
                                                </p>
                                            </form>
                                        </section><!-- .jetpack_subscription_widget -->
                                    </div><!-- #subscribe-newsletter -->                                   
                                </div><!-- end .column-wrapper -->
                                <?php else: 
                                    if ( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'subscriptions' ) && $options['trending_section_enable_subscription'] ) : ?>
                                        <div class="column-wrapper">
                                            <div class="upcoming-courses">
                                            <?php 
                                                $subscription_title = !empty( $options['trending_section_subscription_title'] ) ? $options['trending_section_subscription_title'] : '';
                                                $subscription_subtitle = !empty( $options['trending_section_subscription_subtitle'] ) ? $options['trending_section_subscription_subtitle'] : '';
                                                $subscription_button = !empty( $options['trending_section_subscription_button'] ) ? $options['trending_section_subscription_button'] : esc_html__( 'Get Notified', 'edumag-pro' );
                                                
                                                if( !empty( $subscription_title ) )
                                                    echo '<h3>'. esc_html( $subscription_title ) .'</h3>';
                                                if( !empty( $subscription_subtitle ) )
                                                    echo '<p>'. esc_html( $subscription_subtitle ) .'</p>';
                                                ?>
                                                <div class="view-more">
                                                    <a href="#" class="btn btn-border-white"><?php echo esc_html( $subscription_button ); ?></a>
                                                </div><!--.button-->
                                            </div><!--.upcoming-courses-->
                                            <div id="subscribe-newsletter" class="popup-form">
                                                <section id="blog_subscription-2" class="widget jetpack_subscription_widget">

                                                <?php 
                                                    $subscription_shortcode = '[jetpack_subscription_form title="Receive Newsletter" subscribe_text="Enter your email address to subscribe to this blog and receive notifications of new posts by email." subscribe_button="Sign Me Up" show_subscribers_total="1"]';
                                                    echo do_shortcode( wp_kses_post( $subscription_shortcode ) ); 
                                                ?>
                                                
                                                </section><!-- .jetpack_subscription_widget -->
                                            </div><!-- #subscribe-newsletter -->                                   
                                        </div><!-- end .column-wrapper -->
                                <?php endif;
                                endif; ?>



                            </div><!--.row-->
                        </div><!-- end #tab-1 -->

                        <div id="tab-listview" class="tab-content list-view">
                            <div class="row">
                            <?php 
                                $count = count( $content_details );
                                $index = 1;
                                foreach ( $content_details as $key => $content ) : ?>
                                    <div class="column-wrapper">
                                        <div class="course-item has-post-thumbnail"><!-- use "no-post-thumbnail" class when there is no image -->   
                                            <div class="image-wrapper"> 
                                                <a href="<?php echo esc_url( $content['url'] );?>"><img src="<?php echo esc_url( $content['img_array'][0] ); ?>" alt="<?php echo esc_html( $content['title'] ); ?>"></a>
                                               <?php  if( class_exists( 'TP_Education' ) ){
                                                    $post_id = $content['ID'];
                                                    if( 'tp-class-category' == $options['trending_section_content_type'] ){
                                                        $price = get_post_meta( $post_id, 'tp_class_cost_value', true );          
                                                    }elseif ('tp-course-category' == $options['trending_section_content_type'] ) {
                                                        $price = get_post_meta( $post_id, 'tp_course_price_value', true );
                                                    }
                                                    if( !empty( $price ) ){
                                                        echo '<span class="price-tag">'. esc_html( $price ) .'</span>';
                                                    }
                                                } ?>
                                            </div><!-- end .image-wrapper -->

                                            <div class="course-contents-wrapper">
                                                <div class="course-title">
                                                    <h3><a href="<?php echo esc_url( $content['url'] );?>" class="color-black"></a><?php echo esc_html( $content['title'] ); ?></h3>
                                                </div><!-- end .course-title -->
                                                <?php if( !empty( $content['excerpt'] ) ){ ?>
                                                <div class="course-desc">
                                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                                </div><!-- .course-desc -->
                                                <?php } ?>

                                                <div class="course-footer-content clear">
                                                    <?php if( !empty( $content['likes'] ) ){ ?>
                                                    <div class="pull-left">
                                                        <div class="comments"><?php echo wp_kses_post( $content['likes'] ); ?></div>
                                                    </div><!-- end .pull-left -->
                                                    <?php } ?>
                                                </div><!-- end .slide-description -->
                                            </div><!-- end .course-contents-wrapper -->
                                        </div><!-- end .course-item -->
                                    </div><!-- end .column-wrapper -->
                                <?php endforeach; ?>

                             <?php if( 'demo' == $content_type ) : ?>
                                <div class="column-wrapper">
                                    <div class="upcoming-courses">
                                        <h3><?php esc_html_e( 'upcoming', 'edumag-pro' ); ?> <span class="big-title"><?php esc_html_e( 'courses', 'edumag-pro' ); ?></span></h3>
                                        <p><?php esc_html_e( 'Donec feugiat ultricies accumsan. Fusce sed tempor.', 'edumag-pro' ); ?></p>
                                        <div class="view-more">
                                            <a href="#" class="btn btn-border-white"><?php esc_html_e( 'Get notified', 'edumag-pro' ); ?></a>
                                        </div><!--.button-->
                                    </div><!--.upcoming-courses-->
                                    <div id="subscribe-newsletter" class="popup-form">
                                        <section id="blog_subscription-2" class="widget jetpack_subscription_widget">

                                            <h2 class="widget-title"><?php esc_html_e( 'Receive Newsletter', 'edumag-pro' ); ?></h2>
                                            <form action="#" method="post" accept-charset="utf-8" id="subscribe-blog-blog_subscription-2">
                                                <div id="subscribe-text">
                                                    <p><?php esc_html_e( 'Enter your email address to subscribe to this blog and receive notifications of new posts by email.', 'edumag-pro' ); ?></p>
                                                </div>          

                                                <p id="subscribe-email">
                                                    <label id="jetpack-subscribe-label"><?php esc_html_e( 'Email Address', 'edumag-pro' ); ?></label>
                                                    <input type="email" name="email" required="required" class="required" value="" id="subscribe-field-blog_subscription-2" placeholder="<?php esc_html_e( 'Email Address', 'edumag-pro' ); ?>">
                                                </p>

                                                <p id="subscribe-submit">
                                                    <input type="hidden" name="action" value="subscribe">
                                                    <input type="hidden" name="source" value="http://themepalacedemo.com/foodland-pro/">
                                                    <input type="hidden" name="sub-type" value="widget">
                                                    <input type="hidden" name="redirect_fragment" value="blog_subscription-2">
                                                    <input type="submit" value="Subscribe" name="jetpack_subscriptions_widget">
                                                </p>
                                            </form>
                                        </section><!-- .jetpack_subscription_widget -->
                                    </div><!-- #subscribe-newsletter -->                                   
                                </div><!-- end .column-wrapper -->
                                <?php else: 
                                    if ( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'subscriptions' ) ) : ?>
                                        <div class="column-wrapper">
                                            <div class="upcoming-courses">
                                                <h3><?php esc_html_e( 'upcoming', 'edumag-pro' ); ?> <span class="big-title"><?php esc_html_e( 'courses', 'edumag-pro' ); ?></span></h3>
                                                <p><?php esc_html_e( 'Donec feugiat ultricies accumsan. Fusce sed tempor.', 'edumag-pro' ); ?></p>
                                                <div class="view-more">
                                                    <a href="#" class="btn btn-border-white"><?php esc_html_e( 'Get notified', 'edumag-pro' ); ?></a>
                                                </div><!--.button-->
                                            </div><!--.upcoming-courses-->
                                            <div id="subscribe-newsletter" class="popup-form">
                                                <section id="blog_subscription-2" class="widget jetpack_subscription_widget">

                                                <?php 
                                                    $subscription_shortcode = '[jetpack_subscription_form title="Receive Newsletter" subscribe_text="Enter your email address to subscribe to this blog and receive notifications of new posts by email." subscribe_button="Sign Me Up" show_subscribers_total="1"]';
                                                    echo do_shortcode( wp_kses_post( $subscription_shortcode) ); 
                                                ?>
                                                
                                                </section><!-- .jetpack_subscription_widget -->
                                            </div><!-- #subscribe-newsletter -->                                   
                                        </div><!-- end .column-wrapper -->
                                <?php endif;
                                endif; ?>
                        </div><!-- end .row -->
                    </div><!-- end #tab-2 -->
                </div><!--.courses-list-->
            </div><!--.main-content-->

            <?php if( is_active_sidebar( 'trending_courses_sidebar' ) && ( 'no-sidebar' != $sidebar_layout ) ) : ?>
            <div class="section-sidebar wow fadeInUp" data-wow-delay="0.3s" data-wow-duration="0.3s">
                <?php dynamic_sidebar( 'trending_courses_sidebar' );?>
            </div><!--.section-sidebar-->
            <?php endif; ?>

        </div><!--.container-->
    </section><!--#trending-courses-->
    <?php }
endif;